@@ -94,7 +94,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
           }
           Item::Unexport { name } => {
             if !self.unexports.insert(name.lexeme().to_string()) {
-              return Err(name.token.error(DuplicateUnexport {
+              return Err(name.error(DuplicateUnexport {
                 variable: name.lexeme(),
               }));
             }
@@ -112,7 +112,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
       let variable = assignment.name.lexeme();
 
       if !settings.allow_duplicate_variables && assignments.contains_key(variable) {
-        return Err(assignment.name.token.error(DuplicateVariable { variable }));
+        return Err(assignment.name.error(DuplicateVariable { variable }));
       }
 
       if assignments.get(variable).map_or(true, |original| {
@@ -122,7 +122,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
       }
 
       if self.unexports.contains(variable) {
-        return Err(assignment.name.token.error(ExportUnexported { variable }));
+        return Err(assignment.name.error(ExportUnexported { variable }));
       }
     }
 
@@ -145,7 +145,13 @@ impl<'run, 'src> Analyzer<'run, 'src> {
       }
     }
 
-    let recipes = RecipeResolver::resolve_recipes(&assignments, &settings, deduplicated_recipes)?;
+    let recipes = RecipeResolver::resolve_recipes(
+      &assignments,
+      &ast.module_path,
+      &self.modules,
+      &settings,
+      deduplicated_recipes,
+    )?;
 
     let mut aliases = Table::new();
     while let Some(alias) = self.aliases.pop() {
@@ -166,23 +172,41 @@ impl<'run, 'src> Analyzer<'run, 'src> {
     let source = root.to_owned();
     let root = paths.get(root).unwrap();
 
-    Ok(Justfile {
-      aliases,
-      assignments,
-      default: recipes
+    let mut default = None;
+    for recipe in recipes.values() {
+      if recipe.attributes.contains(AttributeDiscriminant::Default) {
+        if default.is_some() {
+          return Err(recipe.name.error(CompileErrorKind::DuplicateDefault {
+            recipe: recipe.name.lexeme(),
+          }));
+        }
+
+        default = Some(Arc::clone(recipe));
+      }
+    }
+
+    let default = default.or_else(|| {
+      recipes
         .values()
         .filter(|recipe| recipe.name.path == root)
         .fold(None, |accumulator, next| match accumulator {
-          None => Some(Rc::clone(next)),
+          None => Some(Arc::clone(next)),
           Some(previous) => Some(if previous.line_number() < next.line_number() {
             previous
           } else {
-            Rc::clone(next)
+            Arc::clone(next)
           }),
-        }),
+        })
+    });
+
+    Ok(Justfile {
+      aliases,
+      assignments,
+      default,
       doc: doc.filter(|doc| !doc.is_empty()),
       groups: groups.into(),
       loaded: loaded.into(),
+      module_path: ast.module_path.clone(),
       modules: self.modules,
       name,
       recipes,
@@ -229,7 +253,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
 
     for parameter in &recipe.parameters {
       if parameters.contains(parameter.name.lexeme()) {
-        return Err(parameter.name.token.error(DuplicateParameter {
+        return Err(parameter.name.error(DuplicateParameter {
           recipe: recipe.name.lexeme(),
           parameter: parameter.name.lexeme(),
         }));
@@ -292,23 +316,23 @@ impl<'run, 'src> Analyzer<'run, 'src> {
 
   fn resolve_alias<'a>(
     modules: &'a Table<'src, Justfile<'src>>,
-    recipes: &'a Table<'src, Rc<Recipe<'src>>>,
+    recipes: &'a Table<'src, Arc<Recipe<'src>>>,
     alias: Alias<'src, Namepath<'src>>,
   ) -> CompileResult<'src, Alias<'src>> {
-    match Self::alias_target(&alias.target, modules, recipes) {
+    match Self::resolve_recipe(&alias.target, modules, recipes) {
       Some(target) => Ok(alias.resolve(target)),
-      None => Err(alias.name.token.error(UnknownAliasTarget {
+      None => Err(alias.name.error(UnknownAliasTarget {
         alias: alias.name.lexeme(),
         target: alias.target,
       })),
     }
   }
 
-  fn alias_target<'a>(
+  pub(crate) fn resolve_recipe<'a>(
     path: &Namepath<'src>,
     mut modules: &'a Table<'src, Justfile<'src>>,
-    mut recipes: &'a Table<'src, Rc<Recipe<'src>>>,
-  ) -> Option<Rc<Recipe<'src>>> {
+    mut recipes: &'a Table<'src, Arc<Recipe<'src>>>,
+  ) -> Option<Arc<Recipe<'src>>> {
     let (name, path) = path.split_last();
 
     for name in path {
