@@ -12,30 +12,18 @@ pub(crate) struct Color {
 }
 
 impl Color {
-  fn restyle(self, style: Style) -> Self {
-    Self { style, ..self }
-  }
-
-  fn redirect(self, stream: impl IsTerminal) -> Self {
-    Self {
-      is_terminal: stream.is_terminal(),
-      ..self
+  pub(crate) fn active(&self) -> bool {
+    match self.use_color {
+      UseColor::Always => true,
+      UseColor::Never => false,
+      UseColor::Auto => self.is_terminal,
     }
   }
 
-  fn effective_style(&self) -> Style {
-    if self.active() {
-      self.style
-    } else {
-      Style::new()
-    }
+  pub(crate) fn alias(self) -> Self {
+    self.restyle(Style::new().fg(Purple))
   }
 
-  pub(crate) fn auto() -> Self {
-    Self::default()
-  }
-
-  #[cfg(test)]
   pub(crate) fn always() -> Self {
     Self {
       use_color: UseColor::Always,
@@ -43,39 +31,12 @@ impl Color {
     }
   }
 
-  pub(crate) fn never() -> Self {
-    Self {
-      use_color: UseColor::Never,
-      ..Self::default()
-    }
+  pub(crate) fn annotation(self) -> Self {
+    self.restyle(Style::new().fg(Purple))
   }
 
-  pub(crate) fn stderr(self) -> Self {
-    self.redirect(io::stderr())
-  }
-
-  pub(crate) fn stdout(self) -> Self {
-    self.redirect(io::stdout())
-  }
-
-  pub(crate) fn context(self) -> Self {
-    self.restyle(Style::new().fg(Blue).bold())
-  }
-
-  pub(crate) fn doc(self) -> Self {
-    self.restyle(Style::new().fg(Blue))
-  }
-
-  pub(crate) fn error(self) -> Self {
-    self.restyle(Style::new().fg(Red).bold())
-  }
-
-  pub(crate) fn group(self) -> Self {
-    self.restyle(Style::new().fg(Yellow).bold())
-  }
-
-  pub(crate) fn warning(self) -> Self {
-    self.restyle(Style::new().fg(Yellow).bold())
+  pub(crate) fn auto() -> Self {
+    Self::default()
   }
 
   pub(crate) fn banner(self) -> Self {
@@ -90,20 +51,8 @@ impl Color {
     })
   }
 
-  pub(crate) fn parameter(self) -> Self {
-    self.restyle(Style::new().fg(Cyan))
-  }
-
-  pub(crate) fn message(self) -> Self {
-    self.restyle(Style::new().bold())
-  }
-
-  pub(crate) fn annotation(self) -> Self {
-    self.restyle(Style::new().fg(Purple))
-  }
-
-  pub(crate) fn string(self) -> Self {
-    self.restyle(Style::new().fg(Green))
+  pub(crate) fn context(self) -> Self {
+    self.restyle(Style::new().fg(Blue).bold())
   }
 
   pub(crate) fn diff_added(self) -> Self {
@@ -114,11 +63,38 @@ impl Color {
     self.restyle(Style::new().fg(Red))
   }
 
-  pub(crate) fn active(&self) -> bool {
-    match self.use_color {
-      UseColor::Always => true,
-      UseColor::Never => false,
-      UseColor::Auto => self.is_terminal,
+  pub(crate) fn doc(self) -> Self {
+    self.restyle(Style::new().fg(Blue))
+  }
+
+  pub(crate) fn doc_backtick(self) -> Self {
+    self.restyle(Style::new().fg(Cyan))
+  }
+
+  fn effective_style(&self) -> Style {
+    if self.active() {
+      self.style
+    } else {
+      Style::new()
+    }
+  }
+
+  pub(crate) fn error(self) -> Self {
+    self.restyle(Style::new().fg(Red).bold())
+  }
+
+  pub(crate) fn group(self) -> Self {
+    self.restyle(Style::new().fg(Yellow).bold())
+  }
+
+  pub(crate) fn message(self) -> Self {
+    self.restyle(Style::new().bold())
+  }
+
+  pub(crate) fn never() -> Self {
+    Self {
+      use_color: UseColor::Never,
+      ..Self::default()
     }
   }
 
@@ -126,13 +102,44 @@ impl Color {
     self.effective_style().paint(text)
   }
 
+  pub(crate) fn parameter(self) -> Self {
+    self.restyle(Style::new().fg(Cyan))
+  }
+
   pub(crate) fn prefix(&self) -> Prefix {
     self.effective_style().prefix()
   }
 
+  fn redirect(self, stream: impl IsTerminal) -> Self {
+    Self {
+      is_terminal: stream.is_terminal(),
+      ..self
+    }
+  }
+
+  fn restyle(self, style: Style) -> Self {
+    Self { style, ..self }
+  }
+
+  pub(crate) fn stderr(self) -> Self {
+    self.redirect(io::stderr())
+  }
+
+  pub(crate) fn stdout(self) -> Self {
+    self.redirect(io::stdout())
+  }
+
+  pub(crate) fn string(self) -> Self {
+    self.restyle(Style::new().fg(Green))
+  }
+
   pub(crate) fn suffix(&self) -> Suffix {
     self.effective_style().suffix()
   }
+
+  pub(crate) fn warning(self) -> Self {
+    self.restyle(Style::new().fg(Yellow).bold())
+  }
 }
 
 impl From<UseColor> for Color {
