@@ -18,7 +18,7 @@ pub(crate) enum CompileErrorKind<'src> {
     circle: Vec<&'src str>,
   },
   DependencyArgumentCountMismatch {
-    dependency: &'src str,
+    dependency: Namepath<'src>,
     found: usize,
     min: usize,
     max: usize,
@@ -27,6 +27,9 @@ pub(crate) enum CompileErrorKind<'src> {
     attribute: &'src str,
     first: usize,
   },
+  DuplicateDefault {
+    recipe: &'src str,
+  },
   DuplicateParameter {
     recipe: &'src str,
     parameter: &'src str,
@@ -145,7 +148,7 @@ pub(crate) enum CompileErrorKind<'src> {
   },
   UnknownDependency {
     recipe: &'src str,
-    unknown: &'src str,
+    unknown: Namepath<'src>,
   },
   UnknownFunction {
     function: &'src str,
