@@ -4,11 +4,11 @@ use super::*;
 pub(crate) struct Dependency<'src> {
   pub(crate) arguments: Vec<Expression<'src>>,
   #[serde(serialize_with = "keyed::serialize")]
-  pub(crate) recipe: Rc<Recipe<'src>>,
+  pub(crate) recipe: Arc<Recipe<'src>>,
 }
 
-impl<'src> Display for Dependency<'src> {
-  fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
+impl Display for Dependency<'_> {
+  fn fmt(&self, f: &mut Formatter) -> fmt::Result {
     if self.arguments.is_empty() {
       write!(f, "{}", self.recipe.name())
     } else {
