@@ -104,7 +104,6 @@ pub(crate) use {
   edit_distance::edit_distance,
   lexiclean::Lexiclean,
   libc::EXIT_FAILURE,
-  once_cell::sync::Lazy,
   rand::seq::IndexedRandom,
   regex::Regex,
   serde::{
@@ -120,7 +119,7 @@ pub(crate) use {
     ffi::OsString,
     fmt::{self, Debug, Display, Formatter},
     fs,
-    io::{self, Read, Seek, Write},
+    io::{self, Write},
     iter::{self, FromIterator},
     mem,
     ops::Deref,
@@ -128,11 +127,11 @@ pub(crate) use {
     path::{self, Path, PathBuf},
     process::{self, Command, ExitStatus, Stdio},
     str::{self, Chars},
-    sync::{Arc, Mutex, MutexGuard, OnceLock},
+    sync::{Arc, LazyLock, Mutex, MutexGuard, OnceLock},
     thread, vec,
   },
   strum::{Display, EnumDiscriminants, EnumString, IntoStaticStr},
-  tempfile::{tempfile, TempDir},
+  tempfile::TempDir,
   typed_arena::Arena,
   unicode_width::{UnicodeWidthChar, UnicodeWidthStr},
 };
