@@ -3,7 +3,7 @@ use super::*;
 #[derive(PartialEq, Debug, Clone)]
 pub(crate) struct UnresolvedDependency<'src> {
   pub(crate) arguments: Vec<Expression<'src>>,
-  pub(crate) recipe: Name<'src>,
+  pub(crate) recipe: Namepath<'src>,
 }
 
 impl Display for UnresolvedDependency<'_> {
