@@ -5,7 +5,8 @@ pub(crate) type UnresolvedRecipe<'src> = Recipe<'src, UnresolvedDependency<'src>
 impl<'src> UnresolvedRecipe<'src> {
   pub(crate) fn resolve(
     self,
-    resolved: Vec<Rc<Recipe<'src>>>,
+    module_path: &str,
+    resolved: Vec<Arc<Recipe<'src>>>,
   ) -> CompileResult<'src, Recipe<'src>> {
     assert_eq!(
       self.dependencies.len(),
@@ -16,21 +17,19 @@ impl<'src> UnresolvedRecipe<'src> {
     );
 
     for (unresolved, resolved) in self.dependencies.iter().zip(&resolved) {
-      assert_eq!(unresolved.recipe.lexeme(), resolved.name.lexeme());
+      assert_eq!(unresolved.recipe.last().lexeme(), resolved.name.lexeme());
       if !resolved
         .argument_range()
         .contains(&unresolved.arguments.len())
       {
-        return Err(
-          unresolved
-            .recipe
-            .error(CompileErrorKind::DependencyArgumentCountMismatch {
-              dependency: unresolved.recipe.lexeme(),
-              found: unresolved.arguments.len(),
-              min: resolved.min_arguments(),
-              max: resolved.max_arguments(),
-            }),
-        );
+        return Err(unresolved.recipe.last().error(
+          CompileErrorKind::DependencyArgumentCountMismatch {
+            dependency: unresolved.recipe.clone(),
+            found: unresolved.arguments.len(),
+            min: resolved.min_arguments(),
+            max: resolved.max_arguments(),
+          },
+        ));
       }
     }
 
@@ -44,6 +43,14 @@ impl<'src> UnresolvedRecipe<'src> {
       })
       .collect();
 
+    let mut namepath = String::from(module_path);
+
+    if !namepath.is_empty() {
+      namepath.push_str("::");
+    }
+
+    namepath.push_str(self.name.lexeme());
+
     Ok(Recipe {
       attributes: self.attributes,
       body: self.body,
@@ -52,7 +59,7 @@ impl<'src> UnresolvedRecipe<'src> {
       file_depth: self.file_depth,
       import_offsets: self.import_offsets,
       name: self.name,
-      namepath: self.namepath,
+      namepath: Some(namepath),
       parameters: self.parameters,
       priors: self.priors,
       private: self.private,
