@@ -52,6 +52,7 @@ mod assignment;
 mod attributes;
 mod backticks;
 mod byte_order_mark;
+mod ceiling;
 mod changelog;
 mod choose;
 mod command;
@@ -60,6 +61,7 @@ mod conditional;
 mod confirm;
 mod constants;
 mod datetime;
+mod default;
 mod delimiters;
 mod dependencies;
 mod directories;
